using System;
using System.Drawing;
using System.Windows.Forms;
using Microsoft.Win32;
using VideoCaptureLibrary;

namespace VideoCaptureLibraryDemo
{
    class Settings
    {
        private static Point LocationValue;
        private static Size SizeValue;
        private static bool AlwaysOnTopValue = true;
        private static string CaptureFilePathValue = @"c:\capture.avi";
        private static int CaptureFileSizeValue = 0;
        private static string DIBFilePathValue = @"c:\capture.bmp";
        private static VideoCaptureDevice.BitsPerSample BitsPerSampleValue = VideoCaptureDevice.BitsPerSample.Samples16Bits;
        private static VideoCaptureDevice.WaveChannels WaveChannelsValue = VideoCaptureDevice.WaveChannels.Stereo;
        private static int SamplesPerSecondValue = 22050;
        private static int PreviewFrameRateValue = 30;
        private static bool PreviewValue = false;
        private static bool OverlayValue = false;
        private static bool StretchValue = false;
        private static int CaptureFrameRateValue = 30;
        private static bool UseCaptureStartTimeValue = false;
        private static DateTime CaptureStartTimeValue;
        private static bool UseCaptureTimeLimitValue = false;
        private static int CaptureTimeLimitValue = 0;
        private static bool CaptureAudioValue = false;

        //Location Property.
        public static Point Location
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                LocationValue = new Point((int)key.GetValue("Left", 0), (int)key.GetValue("Top", 0));
                return (LocationValue);
            }
            set
            {
                LocationValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("Left", LocationValue.X);
                key.SetValue("Top", LocationValue.Y);
            }
        }

        //Size Property.
        public static Size Size
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                SizeValue = new Size((int)key.GetValue("Width", 0), (int)key.GetValue("Height", 0));
                return (SizeValue);
            }
            set
            {
                SizeValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("Width", SizeValue.Width);
                key.SetValue("Height", SizeValue.Height);
            }
        }

        //Always On Top Property.
        public static bool AlwaysOnTop
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                AlwaysOnTopValue = Boolean.Parse((string)key.GetValue("AlwaysOnTop", "True"));
                return (AlwaysOnTopValue);
            }
            set
            {
                AlwaysOnTopValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("AlwaysOnTop", AlwaysOnTopValue.ToString());
            }
        }

        //CaptureFilePath Property.
        public static string CaptureFilePath
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                CaptureFilePathValue = (string)key.GetValue("CaptureFilePath", @"c:\capture.avi");
                return (CaptureFilePathValue);
            }
            set
            {
                CaptureFilePathValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("CaptureFilePath", CaptureFilePathValue);
            }
        }

        //CaptureFileSize Property.
        public static int CaptureFileSize
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                CaptureFileSizeValue = (int)key.GetValue("CaptureFileSize", 0);
                return (CaptureFileSizeValue);
            }
            set
            {
                CaptureFileSizeValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("CaptureFileSize", CaptureFileSizeValue);
            }
        }

        //DIBFilePath Property.
        public static string DIBFilePath
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                DIBFilePathValue = (string)key.GetValue("DIBFilePath", @"c:\capture.bmp");
                return (DIBFilePathValue);
            }
            set
            {
                DIBFilePathValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("DIBFilePath", DIBFilePathValue);
            }
        }

        //BitsPerSample Property.
        public static VideoCaptureDevice.BitsPerSample BitsPerSample
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                switch ((string)key.GetValue("BitsPerSample", "16-Bits"))
                {
                    case "Samples8Bits":
                        BitsPerSampleValue = VideoCaptureDevice.BitsPerSample.Samples8Bits;
                        break;
                    case "Samples16Bits":
                        BitsPerSampleValue = VideoCaptureDevice.BitsPerSample.Samples16Bits;
                        break;
                }
                return (BitsPerSampleValue);
            }
            set
            {
                BitsPerSampleValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("BitsPerSample", BitsPerSampleValue.ToString());
            }
        }

        //WaveChannels Property.
        public static VideoCaptureDevice.WaveChannels WaveChannels
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                switch ((string)key.GetValue("WaveChannels", "Stereo"))
                {
                    case "Mono":
                        WaveChannelsValue = VideoCaptureDevice.WaveChannels.Mono;
                        break;
                    case "Stereo":
                        WaveChannelsValue = VideoCaptureDevice.WaveChannels.Stereo;
                        break;
                }
                return (WaveChannelsValue);
            }
            set
            {
                WaveChannelsValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("WaveChannels", WaveChannelsValue.ToString());
            }
        }

        //SamplesPerSecond Property.
        public static int SamplesPerSecond
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                SamplesPerSecondValue = (int)key.GetValue("SamplesPerSecond", 22050);
                return (SamplesPerSecondValue);
            }
            set
            {
                SamplesPerSecondValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("SamplesPerSecond", SamplesPerSecondValue);
            }
        }

        //PreviewFrameRate Property.
        public static int PreviewFrameRate
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                PreviewFrameRateValue = (int)key.GetValue("PreviewFrameRate", 30);
                return (PreviewFrameRateValue);
            }
            set
            {
                PreviewFrameRateValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("PreviewFrameRate", PreviewFrameRateValue);
            }
        }

        //Preview Property.
        public static bool Preview
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                PreviewValue = Boolean.Parse((string)key.GetValue("Preview", "False"));
                return (PreviewValue);
            }
            set
            {
                PreviewValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("Preview", PreviewValue.ToString());
            }
        }

        //Overlay Property.
        public static bool Overlay
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                OverlayValue = Boolean.Parse((string)key.GetValue("Overlay", "False"));
                return (OverlayValue);
            }
            set
            {
                OverlayValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("Overlay", OverlayValue.ToString());
            }
        }

        //Preview Property.
        public static bool Stretch
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                StretchValue = Boolean.Parse((string)key.GetValue("Stretch", "False"));
                return (StretchValue);
            }
            set
            {
                StretchValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("Stretch", StretchValue.ToString());
            }
        }

        //CaptureFrameRate Property.
        public static int CaptureFrameRate
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                CaptureFrameRateValue = (int)key.GetValue("CaptureFrameRate", 30);
                return (CaptureFrameRateValue);
            }
            set
            {
                CaptureFrameRateValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("CaptureFrameRate", CaptureFrameRateValue);
            }
        }

        //UseCaptureStartTime Property.
        public static bool UseCaptureStartTime
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                UseCaptureStartTimeValue = Boolean.Parse((string)key.GetValue("UseCaptureStartTime", "False"));
                return (UseCaptureStartTimeValue);
            }
            set
            {
                UseCaptureStartTimeValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("UseCaptureStartTime", UseCaptureStartTimeValue.ToString());
            }
        }

        //CaptureStartTime Property.
        public static DateTime CaptureStartTime
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                CaptureStartTimeValue = DateTime.Parse((string)key.GetValue("CaptureStartTime", DateTime.Now.ToString()));
                return (CaptureStartTimeValue);
            }
            set
            {
                CaptureStartTimeValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("CaptureStartTime", CaptureStartTimeValue.ToString());
            }
        }

        //UseCaptureTimeLimit Property.
        public static bool UseCaptureTimeLimit
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                UseCaptureTimeLimitValue = Boolean.Parse((string)key.GetValue("UseCaptureTimeLimit", "False"));
                return (UseCaptureTimeLimitValue);
            }
            set
            {
                UseCaptureTimeLimitValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("UseCaptureTimeLimit", UseCaptureTimeLimitValue.ToString());
            }
        }

        //CaptureTimeLimit Property.
        public static int CaptureTimeLimit
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                CaptureTimeLimitValue = (int)key.GetValue("CaptureTimeLimit", 0);
                return (CaptureTimeLimitValue);
            }
            set
            {
                CaptureTimeLimitValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("CaptureTimeLimit", CaptureTimeLimitValue);
            }
        }

        //CaptureAudio Property.
        public static bool CaptureAudio
        {
            get
            {
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                if (key == null) key = Registry.CurrentUser.CreateSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct);
                CaptureAudioValue = Boolean.Parse((string)key.GetValue("CaptureAudio", "False"));
                return (CaptureAudioValue);
            }
            set
            {
                CaptureAudioValue = value;
                RegistryKey key = Registry.CurrentUser.OpenSubKey("Software\\" + GetAssemblyInfo.AssemblyCompany + "\\" + GetAssemblyInfo.AssemblyProduct, true);
                key.SetValue("CaptureAudio", CaptureAudioValue.ToString());
            }
        }
    }
}
